<?xml version="1.0"?>

<st-source>
<time-stamp>From VisualWorks®, 7.3.1 of April 20, 2005 on January 17, 2007 at 7:52:17 am</time-stamp>


<methods>
<class-id>PROVISO.ProbeMonitorProxy</class-id> <category>controlling</category>

<body package="PV-SNMP Collector" selector="collectorClientForSubelementId:">collectorClientForSubelementId: targetId 
	"&lt;RemoteSNMPCollector&gt; Given a subelement id, lookup or create a RemoteSNMPCollector"
	
	| collectorNumber hostAndPort returnedValue |
	returnedValue := nil.
	[collectorNumber := self collectorForSubelementId: targetId] 
		on: Error
		do: 
			[:err | 
			self logInternalError: 
				'Error getting collector# for targetId ' , targetId printString , ': ' , 
					err printString.
			^nil].
	[hostAndPort := self hostAndPortForCollector: collectorNumber] 
		on: Error
		do: 
			[:err | 
			self logInternalError: 
				'Error getting host/port for collector# ' , collectorNumber printString , ': ' , 
					err printString.
			^nil].
	(hostAndPort key isNil or: [hostAndPort value isNil]) 
		ifTrue: 
			[self logInternalError: 
				'Error no registered host/port for collector# ' , collectorNumber printString.
			^nil].
	[returnedValue := 
		self collectors 
			at: hostAndPort
			ifAbsentPut: 
				[RemoteSNMPCollector 
					hostName: hostAndPort key
					port: hostAndPort value asNumber]] 
						on: Error
						do: 
							[:err | 
							self logInternalError: 
								'Error getting Cnx to collector ' , hostAndPort key asString , ':' , 
									hostAndPort value asString , ': ' , err printString.
							^nil].
	^returnedValue</body>
</methods>

<methods>
<class-id>PROVISO.ProbeMonitorProxy</class-id> <category>private</category>

<body package="PV-SNMP Collector" selector="doCorbaApi:">doCorbaApi: aBlock

	
	[self requestLimiter
		do: [| returnedValue |
			self logExecuteCommand: aBlock.
			returnedValue := aBlock value.
			self logCommandOk: returnedValue.
			^ returnedValue]
		ifLimitBreached: [self raiseBusyError]]
			on: Error
			do: [:anError | 
				self logCommandError: anError.
				anError raiseAsCorbaSaaError]</body>
</methods>

<methods>
<class-id>PROVISO.ProbeMonitorProxy</class-id> <category>logging</category>

<body package="PV-SNMP Collector" selector="logCommandError:">logCommandError: anException
	self system
		logInfo: #CMD_PROXY_ERROR
		template: 'proxy command fail with &lt;1s&gt;'
		arguments: (Array with: anException printString ).
	^self</body>
</methods>

<methods>
<class-id>PROVISO.ProbeMonitorProxy</class-id> <category>logging</category>

<body package="PV-SNMP Collector" selector="logCommandOk:">logCommandOk: aValue 
	
	[self system 
		logInfo: #CMD_PROXY_OK
		template: 'proxy command return with &lt;1s&gt;'
		arguments: (Array with: aValue printString)] 
			on: Error
			do: 
				[:err | 
				self system 
					logInfo: #CMD_PROXY_OK
					template: 'proxy command XX encountered error &lt;1s&gt;'
					arguments: (Array with: err printString)].
	^self</body>
</methods>

<methods>
<class-id>PROVISO.ProbeMonitorProxy</class-id> <category>logging</category>

<body package="PV-SNMP Collector" selector="logExecuteCommand:">logExecuteCommand: aBlock 
	
	[self system 
		logInfo: #CMD_PROXY
		template: 'proxy command &lt;1s&gt; with arguments &lt;2s&gt;'
		arguments: 
			(Array 
				with: aBlock printString
				with: aBlock copiedValues printString)] 
					on: Error
					do: 
						[:err | 
						self system 
							logInfo: #CMD_PROXY
							template: 'proxy command XX with arguments XX generated error &lt;1s&gt;'
							arguments: (Array with: err printString)].
	^self</body>
</methods>

<methods>
<class-id>PROVISO.ProbeMonitorProxy</class-id> <category>logging</category>

<body package="PV-SNMP Collector" selector="logInternalError:">logInternalError: aMessage
	self system
		logInfo: #CMD_PROXY_ERROR
		template: 'proxy internal error &lt;1s&gt;'
		arguments: (Array with: aMessage printString ).
	^self</body>
</methods>

</st-source>
